@@ -15,11 +15,11 @@
 #define LLVM_CONFIG_H
 
 /* Define if LLVM_ENABLE_DUMP is enabled */
-/* #undef LLVM_ENABLE_DUMP */
+#define LLVM_ENABLE_DUMP
 
 /* Target triple LLVM will generate code for by default */
 /* Doesn't use `cmakedefine` because it is allowed to be empty. */
-#define LLVM_DEFAULT_TARGET_TRIPLE "i686-pc-linux-gnu"
+#define LLVM_DEFAULT_TARGET_TRIPLE "i686-pc-windows-cygnus"
 
 /* Define if threads enabled */
 #define LLVM_ENABLE_THREADS 1
@@ -28,7 +28,7 @@
 #define LLVM_HAS_ATOMICS 1
 
 /* Host triple LLVM will be executed on */
-#define LLVM_HOST_TRIPLE "i686-pc-linux-gnu"
+#define LLVM_HOST_TRIPLE "i686-pc-windows-cygnus"
 
 /* LLVM architecture name for the native architecture, if available */
 #define LLVM_NATIVE_ARCH X86
@@ -54,81 +54,6 @@
 /* LLVM name for the native target MCA init function, if available */
 /* #undef LLVM_NATIVE_TARGETMCA */
 
-/* Define if the AArch64 target is built in */
-#define LLVM_HAS_AARCH64_TARGET 1
-
-/* Define if the AMDGPU target is built in */
-#define LLVM_HAS_AMDGPU_TARGET 1
-
-/* Define if the ARC target is built in */
-#define LLVM_HAS_ARC_TARGET 0
-
-/* Define if the ARM target is built in */
-#define LLVM_HAS_ARM_TARGET 1
-
-/* Define if the AVR target is built in */
-#define LLVM_HAS_AVR_TARGET 1
-
-/* Define if the BPF target is built in */
-#define LLVM_HAS_BPF_TARGET 1
-
-/* Define if the CSKY target is built in */
-#define LLVM_HAS_CSKY_TARGET 0
-
-/* Define if the DirectX target is built in */
-#define LLVM_HAS_DIRECTX_TARGET 0
-
-/* Define if the Hexagon target is built in */
-#define LLVM_HAS_HEXAGON_TARGET 1
-
-/* Define if the Lanai target is built in */
-#define LLVM_HAS_LANAI_TARGET 1
-
-/* Define if the LoongArch target is built in */
-#define LLVM_HAS_LOONGARCH_TARGET 1
-
-/* Define if the M68k target is built in */
-#define LLVM_HAS_M68K_TARGET 0
-
-/* Define if the Mips target is built in */
-#define LLVM_HAS_MIPS_TARGET 1
-
-/* Define if the MSP430 target is built in */
-#define LLVM_HAS_MSP430_TARGET 1
-
-/* Define if the NVPTX target is built in */
-#define LLVM_HAS_NVPTX_TARGET 1
-
-/* Define if the PowerPC target is built in */
-#define LLVM_HAS_POWERPC_TARGET 1
-
-/* Define if the RISCV target is built in */
-#define LLVM_HAS_RISCV_TARGET 1
-
-/* Define if the Sparc target is built in */
-#define LLVM_HAS_SPARC_TARGET 1
-
-/* Define if the SPIRV target is built in */
-#define LLVM_HAS_SPIRV_TARGET 0
-
-/* Define if the SystemZ target is built in */
-#define LLVM_HAS_SYSTEMZ_TARGET 1
-
-/* Define if the VE target is built in */
-#define LLVM_HAS_VE_TARGET 1
-
-/* Define if the WebAssembly target is built in */
-#define LLVM_HAS_WEBASSEMBLY_TARGET 1
-
-/* Define if the X86 target is built in */
-#define LLVM_HAS_X86_TARGET 1
-
-/* Define if the XCore target is built in */
-#define LLVM_HAS_XCORE_TARGET 1
-
-/* Define if the Xtensa target is built in */
-#define LLVM_HAS_XTENSA_TARGET 0
-
 /* Define if this is Unixish platform */
 #define LLVM_ON_UNIX 1
 
@@ -139,19 +64,19 @@
 #define LLVM_USE_OPROFILE 0
 
 /* Define if we have the perf JIT-support library */
-#define LLVM_USE_PERF 1
+#define LLVM_USE_PERF 0
 
 /* Major version of the LLVM API */
-#define LLVM_VERSION_MAJOR 18
+#define LLVM_VERSION_MAJOR 21
 
 /* Minor version of the LLVM API */
 #define LLVM_VERSION_MINOR 1
 
 /* Patch version of the LLVM API */
-#define LLVM_VERSION_PATCH 8
+#define LLVM_VERSION_PATCH 1
 
 /* LLVM version string */
-#define LLVM_VERSION_STRING "18.1.8"
+#define LLVM_VERSION_STRING "21.1.1"
 
 /* Whether LLVM records statistics for use with GetStatistics(),
  * PrintStatistics() or PrintStatisticsJSON()
@@ -162,7 +87,7 @@
 /* #undef LLVM_WITH_Z3 */
 
 /* Define if we have curl and want to use it */
-#define LLVM_ENABLE_CURL 1
+/* #undef LLVM_ENABLE_CURL */
 
 /* Define if we have cpp-httplib and want to use it */
 /* #undef LLVM_ENABLE_HTTPLIB */
@@ -185,6 +110,12 @@
 /* Define if building LLVM with BUILD_SHARED_LIBS */
 /* #undef LLVM_BUILD_SHARED_LIBS */
 
+/* Define if exporting LLVM public interface for shared library */
+#define LLVM_ENABLE_LLVM_EXPORT_ANNOTATIONS
+
+/* Define if exporting LLVM-C public interface for shared library */
+#define LLVM_ENABLE_LLVM_C_EXPORT_ANNOTATIONS
+
 /* Define if building LLVM with LLVM_FORCE_USE_OLD_TOOLCHAIN_LIBS */
 /* #undef LLVM_FORCE_USE_OLD_TOOLCHAIN */
 
@@ -198,4 +129,18 @@
 /* Define if plugins enabled */
 #define LLVM_ENABLE_PLUGINS
 
+/* Define if logf128 is available */
+/* #undef LLVM_HAS_LOGF128 */
+
+/* Define if building LLVM with LLVM_ENABLE_TELEMETRY */
+#define LLVM_ENABLE_TELEMETRY 1
+
+/* Define to 1 to enable expensive checks for debug location coverage checking,
+   and to 0 otherwise. */
+#define LLVM_ENABLE_DEBUGLOC_TRACKING_COVERAGE 0
+
+/* Define to 1 to enable expensive tracking of the origin of debug location
+   coverage bugs, and to 0 otherwise. */
+#define LLVM_ENABLE_DEBUGLOC_TRACKING_ORIGIN 0
+
 #endif
